"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShadowDecorator = exports.ScaleDecorator = exports.OpacityDecorator = void 0;
Object.defineProperty(exports, "useOnCellActiveAnimation", {
  enumerable: true,
  get: function () {
    return _useOnCellActiveAnimation.useOnCellActiveAnimation;
  }
});

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _draggableFlatListContext = require("../context/draggableFlatListContext");

var _useOnCellActiveAnimation = require("../hooks/useOnCellActiveAnimation");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ScaleDecorator = _ref => {
  let {
    activeScale = 1.1,
    children
  } = _ref;
  const {
    isActive,
    onActiveAnim
  } = (0, _useOnCellActiveAnimation.useOnCellActiveAnimation)({
    animationConfig: {
      mass: 0.1,
      restDisplacementThreshold: 0.0001
    }
  });
  const {
    horizontal
  } = (0, _draggableFlatListContext.useDraggableFlatListContext)();
  const style = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const animScale = (0, _reactNativeReanimated.interpolate)(onActiveAnim.value, [0, 1], [1, activeScale]);
    const scale = isActive ? animScale : 1;
    return {
      transform: [{
        scaleX: scale
      }, {
        scaleY: scale
      }]
    };
  }, [isActive]);
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [style, horizontal && styles.horizontal]
  }, children);
};

exports.ScaleDecorator = ScaleDecorator;

const ShadowDecorator = _ref2 => {
  let {
    elevation = 10,
    color = "black",
    opacity = 0.25,
    radius = 5,
    children
  } = _ref2;
  const {
    isActive,
    onActiveAnim
  } = (0, _useOnCellActiveAnimation.useOnCellActiveAnimation)();
  const {
    horizontal
  } = (0, _draggableFlatListContext.useDraggableFlatListContext)();
  const style = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const shadowOpacity = onActiveAnim.value * opacity;
    return {
      elevation: isActive ? elevation : 0,
      shadowRadius: isActive ? radius : 0,
      shadowColor: isActive ? color : "transparent",
      shadowOpacity: isActive ? shadowOpacity : 0
    };
  }, [isActive, onActiveAnim]);
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [style, horizontal && styles.horizontal]
  }, children);
};

exports.ShadowDecorator = ShadowDecorator;

const OpacityDecorator = _ref3 => {
  let {
    activeOpacity = 0.25,
    children
  } = _ref3;
  const {
    isActive,
    onActiveAnim
  } = (0, _useOnCellActiveAnimation.useOnCellActiveAnimation)();
  const {
    horizontal
  } = (0, _draggableFlatListContext.useDraggableFlatListContext)();
  const style = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const opacity = (0, _reactNativeReanimated.interpolate)(onActiveAnim.value, [0, 1], [1, activeOpacity]);
    return {
      opacity: isActive ? opacity : 1
    };
  }, [isActive]);
  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [style, horizontal && styles.horizontal]
  }, children);
};

exports.OpacityDecorator = OpacityDecorator;

const styles = _reactNative.StyleSheet.create({
  horizontal: {
    flexDirection: "row",
    flex: 1
  }
});
//# sourceMappingURL=CellDecorators.js.map