"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _draggableFlatListContext = require("../context/draggableFlatListContext");

var _constants = require("../constants");

var _useCellTranslate = require("../hooks/useCellTranslate");

var _utils = require("../utils");

var _refContext = require("../context/refContext");

var _animatedValueContext = require("../context/animatedValueContext");

var _cellContext = _interopRequireDefault(require("../context/cellContext"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function CellRendererComponent(props) {
  const {
    item,
    index,
    onLayout,
    children,
    ...rest
  } = props;
  const currentIndexAnim = (0, _reactNativeReanimated.useSharedValue)(index);
  (0, _react.useEffect)(() => {
    // If we set the index immediately the newly-ordered data can get out of sync
    // with the activeIndexAnim, and cause the wrong item to momentarily become the
    // "active item", which causes a flicker.
    requestAnimationFrame(() => {
      currentIndexAnim.value = index;
    });
  }, [index]);
  const viewRef = (0, _react.useRef)(null);
  const {
    cellDataRef,
    propsRef,
    containerRef
  } = (0, _refContext.useRefs)();
  const {
    horizontalAnim,
    scrollOffset
  } = (0, _animatedValueContext.useAnimatedValues)();
  const {
    activeKey,
    keyExtractor,
    horizontal
  } = (0, _draggableFlatListContext.useDraggableFlatListContext)();
  const key = keyExtractor(item, index);
  const offset = (0, _reactNativeReanimated.useSharedValue)(-1);
  const size = (0, _reactNativeReanimated.useSharedValue)(-1);
  const translate = (0, _useCellTranslate.useCellTranslate)({
    cellOffset: offset,
    cellSize: size,
    cellIndex: currentIndexAnim
  });
  const isActive = activeKey === key;
  const dragInProgress = !!activeKey;
  const animStyle = (0, _reactNativeReanimated.useAnimatedStyle)(() => {
    const _translate = dragInProgress ? translate.value : 0;

    return {
      transform: [horizontalAnim.value ? {
        translateX: _translate
      } : {
        translateY: _translate
      }]
    };
  }, [dragInProgress, translate]);
  const updateCellMeasurements = (0, _react.useCallback)(() => {
    const onSuccess = (x, y, w, h) => {
      if (_constants.isWeb && horizontal) x += scrollOffset.value;
      const cellOffset = horizontal ? x : y;
      const cellSize = horizontal ? w : h;
      cellDataRef.current.set(key, {
        measurements: {
          size: cellSize,
          offset: cellOffset
        }
      });
      size.value = cellSize;
      offset.value = cellOffset;
    };

    const onFail = () => {
      var _propsRef$current;

      if ((_propsRef$current = propsRef.current) !== null && _propsRef$current !== void 0 && _propsRef$current.debug) {
        console.log(`## on measure fail, index: ${index}`);
      }
    };

    const containerNode = containerRef.current;
    const viewNode = viewRef.current;
    const nodeHandle = containerNode;

    if (viewNode && nodeHandle) {
      //@ts-ignore
      viewNode.measureLayout(nodeHandle, onSuccess, onFail);
    }
  }, [cellDataRef, horizontal, index, key, offset, propsRef, size, scrollOffset, containerRef]);
  (0, _react.useEffect)(() => {
    if (_constants.isWeb) {
      // onLayout isn't called on web when the cell index changes, so we manually re-measure
      updateCellMeasurements();
    }
  }, [index, updateCellMeasurements]);
  const onCellLayout = (0, _react.useCallback)(e => {
    updateCellMeasurements();
    if (onLayout) onLayout(e);
  }, [updateCellMeasurements, onLayout]); // changing zIndex may crash android, but seems to work ok as of RN 68:
  // https://github.com/facebook/react-native/issues/28751

  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, _extends({}, rest, {
    ref: viewRef,
    onLayout: onCellLayout,
    style: [_constants.isAndroid && {
      elevation: isActive ? 1 : 0
    }, {
      flexDirection: horizontal ? "row" : "column"
    }, {
      zIndex: isActive ? 999 : 0
    }],
    pointerEvents: activeKey ? "none" : "auto"
  }), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, _extends({}, rest, {
    // Including both animated styles and non-animated styles 
    // causes react-native-web to ignore updates in non-animated styles. 
    // Solution is to separate animated styles from non-animated styles
    style: [props.style, animStyle]
  }), /*#__PURE__*/_react.default.createElement(_cellContext.default, {
    isActive: isActive
  }, children)));
}

var _default = (0, _utils.typedMemo)(CellRendererComponent);

exports.default = _default;
//# sourceMappingURL=CellRendererComponent.js.map