"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNativeGestureHandler = require("react-native-gesture-handler");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _CellRendererComponent = _interopRequireDefault(require("./CellRendererComponent"));

var _constants = require("../constants");

var _PlaceholderItem = _interopRequireDefault(require("./PlaceholderItem"));

var _RowItem = _interopRequireDefault(require("./RowItem"));

var _propsContext = _interopRequireDefault(require("../context/propsContext"));

var _animatedValueContext = _interopRequireWildcard(require("../context/animatedValueContext"));

var _refContext = _interopRequireWildcard(require("../context/refContext"));

var _draggableFlatListContext = _interopRequireDefault(require("../context/draggableFlatListContext"));

var _useAutoScroll = require("../hooks/useAutoScroll");

var _useIdentityRetainingCallback = require("../hooks/useIdentityRetainingCallback");

var _ScrollOffsetListener = _interopRequireDefault(require("./ScrollOffsetListener"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const AnimatedFlatList = _reactNativeReanimated.default.createAnimatedComponent(_reactNativeGestureHandler.FlatList);

function DraggableFlatListInner(props) {
  const {
    cellDataRef,
    containerRef,
    flatlistRef,
    keyToIndexRef,
    propsRef,
    animationConfigRef
  } = (0, _refContext.useRefs)();
  const {
    activeCellOffset,
    activeCellSize,
    activeIndexAnim,
    containerSize,
    scrollOffset,
    scrollViewSize,
    spacerIndexAnim,
    horizontalAnim,
    placeholderOffset,
    touchTranslate,
    autoScrollDistance,
    panGestureState,
    isTouchActiveNative,
    disabled
  } = (0, _animatedValueContext.useAnimatedValues)();
  const {
    dragHitSlop = _constants.DEFAULT_PROPS.dragHitSlop,
    scrollEnabled = _constants.DEFAULT_PROPS.scrollEnabled,
    activationDistance: activationDistanceProp = _constants.DEFAULT_PROPS.activationDistance
  } = props;
  const [activeKey, setActiveKey] = (0, _react.useState)(null);
  const keyExtractor = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)((item, index) => {
    if (!props.keyExtractor) {
      throw new Error("You must provide a keyExtractor to DraggableFlatList");
    }

    return props.keyExtractor(item, index);
  });
  (0, _react.useLayoutEffect)(() => {
    props.data.forEach((d, i) => {
      const key = keyExtractor(d, i);
      keyToIndexRef.current.set(key, i);
    });
  }, [props.data, keyExtractor, keyToIndexRef]); // Reset hover state whenever data changes

  (0, _react.useMemo)(() => {
    requestAnimationFrame(() => {
      activeIndexAnim.value = -1;
      spacerIndexAnim.value = -1;
      touchTranslate.value = 0;
      activeCellSize.value = -1;
      activeCellOffset.value = -1;
    });
  }, [props.data]);
  const drag = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(activeKey => {
    if (disabled.value) return;
    const index = keyToIndexRef.current.get(activeKey);
    const cellData = cellDataRef.current.get(activeKey);

    if (cellData) {
      activeCellOffset.value = cellData.measurements.offset;
      activeCellSize.value = cellData.measurements.size;
    }

    const {
      onDragBegin
    } = propsRef.current;

    if (index !== undefined) {
      spacerIndexAnim.value = index;
      activeIndexAnim.value = index;
      setActiveKey(activeKey);
      onDragBegin === null || onDragBegin === void 0 ? void 0 : onDragBegin(index);
    }
  });

  const onContainerLayout = _ref => {
    let {
      nativeEvent: {
        layout
      }
    } = _ref;
    const {
      width,
      height
    } = layout;
    containerSize.value = props.horizontal ? width : height;
  };

  const onListContentSizeChange = (w, h) => {
    var _props$onContentSizeC;

    scrollViewSize.value = props.horizontal ? w : h;
    (_props$onContentSizeC = props.onContentSizeChange) === null || _props$onContentSizeC === void 0 ? void 0 : _props$onContentSizeC.call(props, w, h);
  };

  const onContainerTouchStart = () => {
    isTouchActiveNative.value = true;
    return false;
  };

  const onContainerTouchEnd = () => {
    isTouchActiveNative.value = false;
  };

  let dynamicProps = {};

  if (activationDistanceProp) {
    const activeOffset = [-activationDistanceProp, activationDistanceProp];
    dynamicProps = props.horizontal ? {
      activeOffsetX: activeOffset
    } : {
      activeOffsetY: activeOffset
    };
  }

  const extraData = (0, _react.useMemo)(() => ({
    activeKey,
    extraData: props.extraData
  }), [activeKey, props.extraData]);
  const renderItem = (0, _react.useCallback)(_ref2 => {
    let {
      item,
      index
    } = _ref2;
    const key = keyExtractor(item, index);

    if (index !== keyToIndexRef.current.get(key)) {
      keyToIndexRef.current.set(key, index);
    }

    return /*#__PURE__*/_react.default.createElement(_RowItem.default, {
      item: item,
      itemKey: key,
      renderItem: props.renderItem,
      drag: drag,
      extraData: props.extraData
    });
  }, [props.renderItem, props.extraData, drag, keyExtractor]);
  const onRelease = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(index => {
    var _props$onRelease;

    (_props$onRelease = props.onRelease) === null || _props$onRelease === void 0 ? void 0 : _props$onRelease.call(props, index);
  });
  const onDragEnd = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(_ref3 => {
    let {
      from,
      to
    } = _ref3;
    const {
      onDragEnd,
      data
    } = props;

    if (onDragEnd) {
      const newData = [...data];

      if (from !== to) {
        newData.splice(from, 1);
        newData.splice(to, 0, data[from]);
      }

      onDragEnd({
        from,
        to,
        data: newData
      });
      requestAnimationFrame(() => {
        setActiveKey(null);
      });
    }
  }); // Handle case where user ends drag without moving their finger.

  (0, _reactNativeReanimated.useAnimatedReaction)(() => {
    return isTouchActiveNative.value;
  }, (cur, prev) => {
    if (cur !== prev && !cur) {
      const hasMoved = !!touchTranslate.value;

      if (!hasMoved && activeIndexAnim.value >= 0 && !disabled.value) {
        (0, _reactNativeReanimated.runOnJS)(onDragEnd)({
          from: activeIndexAnim.value,
          to: spacerIndexAnim.value
        });
      }
    }
  }, [isTouchActiveNative, onDragEnd]);
  const onGestureEvent = (0, _reactNativeReanimated.useAnimatedGestureHandler)({
    onStart: evt => {
      if (disabled.value) return;
      panGestureState.value = evt.state;
    },
    onActive: evt => {
      if (disabled.value) return;
      panGestureState.value = evt.state;
      const translation = horizontalAnim.value ? evt.translationX : evt.translationY;
      touchTranslate.value = translation;
    },
    onEnd: evt => {
      // Set touch val to current translate val
      isTouchActiveNative.value = false;
      const translation = horizontalAnim.value ? evt.translationX : evt.translationY;
      touchTranslate.value = translation + autoScrollDistance.value;
      panGestureState.value = evt.state; // Only call onDragEnd if actually dragging a cell

      if (activeIndexAnim.value === -1 || disabled.value) return;
      disabled.value = true;
      (0, _reactNativeReanimated.runOnJS)(onRelease)(activeIndexAnim.value);
      const springTo = placeholderOffset.value - activeCellOffset.value;
      touchTranslate.value = (0, _reactNativeReanimated.withSpring)(springTo, animationConfigRef.current, () => {
        (0, _reactNativeReanimated.runOnJS)(onDragEnd)({
          from: activeIndexAnim.value,
          to: spacerIndexAnim.value
        });
        disabled.value = false;
      });
    }
  }, []);
  const onScroll = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(scrollOffset => {
    var _props$onScrollOffset;

    (_props$onScrollOffset = props.onScrollOffsetChange) === null || _props$onScrollOffset === void 0 ? void 0 : _props$onScrollOffset.call(props, scrollOffset);
  });
  const scrollHandler = (0, _reactNativeReanimated.useAnimatedScrollHandler)({
    onScroll: evt => {
      scrollOffset.value = horizontalAnim.value ? evt.contentOffset.x : evt.contentOffset.y;
      (0, _reactNativeReanimated.runOnJS)(onScroll)(scrollOffset.value);
    }
  }, [horizontalAnim]);
  (0, _useAutoScroll.useAutoScroll)();
  return /*#__PURE__*/_react.default.createElement(_draggableFlatListContext.default, {
    activeKey: activeKey,
    keyExtractor: keyExtractor,
    horizontal: !!props.horizontal
  }, /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.PanGestureHandler, _extends({
    hitSlop: dragHitSlop,
    onGestureEvent: onGestureEvent,
    simultaneousHandlers: props.simultaneousHandlers
  }, dynamicProps), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: props.containerStyle,
    ref: containerRef,
    onLayout: onContainerLayout,
    onTouchEnd: onContainerTouchEnd,
    onStartShouldSetResponderCapture: onContainerTouchStart //@ts-ignore
    ,
    onClick: onContainerTouchEnd
  }, props.renderPlaceholder && /*#__PURE__*/_react.default.createElement(_PlaceholderItem.default, {
    renderPlaceholder: props.renderPlaceholder
  }), /*#__PURE__*/_react.default.createElement(AnimatedFlatList, _extends({}, props, {
    data: props.data,
    CellRendererComponent: _CellRendererComponent.default,
    ref: flatlistRef,
    onContentSizeChange: onListContentSizeChange,
    scrollEnabled: !activeKey && scrollEnabled,
    renderItem: renderItem,
    extraData: extraData,
    keyExtractor: keyExtractor,
    onScroll: scrollHandler,
    scrollEventThrottle: 16,
    simultaneousHandlers: props.simultaneousHandlers,
    removeClippedSubviews: false
  })), !!props.onScrollOffsetChange && /*#__PURE__*/_react.default.createElement(_ScrollOffsetListener.default, {
    onScrollOffsetChange: props.onScrollOffsetChange,
    scrollOffset: scrollOffset
  }))));
}

function DraggableFlatList(props, ref) {
  return /*#__PURE__*/_react.default.createElement(_propsContext.default, props, /*#__PURE__*/_react.default.createElement(_animatedValueContext.default, null, /*#__PURE__*/_react.default.createElement(_refContext.default, {
    flatListRef: ref
  }, /*#__PURE__*/_react.default.createElement(DraggableFlatListInner, props))));
} // Generic forwarded ref type assertion taken from:
// https://fettblog.eu/typescript-react-generic-forward-refs/#option-1%3A-type-assertion


var _default = /*#__PURE__*/_react.default.forwardRef(DraggableFlatList);

exports.default = _default;
//# sourceMappingURL=DraggableFlatList.js.map