"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NestableDraggableFlatList = NestableDraggableFlatList;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _DraggableFlatList = _interopRequireDefault(require("../components/DraggableFlatList"));

var _nestableScrollContainerContext = require("../context/nestableScrollContainerContext");

var _useNestedAutoScroll = require("../hooks/useNestedAutoScroll");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function NestableDraggableFlatList(props) {
  const hasSuppressedWarnings = (0, _react.useRef)(false);

  if (!hasSuppressedWarnings.current) {
    _reactNative.LogBox.ignoreLogs(["VirtualizedLists should never be nested inside plain ScrollViews with the same orientation because it can break windowing"]); // Ignore log notification by message
    //@ts-ignore


    console.reportErrorsAsExceptions = false;
    hasSuppressedWarnings.current = true;
  }

  const {
    scrollableRef,
    outerScrollOffset,
    setOuterScrollEnabled
  } = (0, _nestableScrollContainerContext.useSafeNestableScrollContainerContext)();
  const listVerticalOffset = (0, _reactNativeReanimated.useSharedValue)(0);
  const viewRef = (0, _react.useRef)(null);
  const [animVals, setAnimVals] = (0, _react.useState)({});
  const defaultHoverOffset = (0, _reactNativeReanimated.useSharedValue)(0);
  const [listHoverOffset, setListHoverOffset] = (0, _react.useState)(defaultHoverOffset);
  const hoverOffset = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return listHoverOffset.value + listVerticalOffset.value;
  }, [listHoverOffset]);
  (0, _useNestedAutoScroll.useNestedAutoScroll)({ ...animVals,
    hoverOffset
  });

  const onListContainerLayout = async () => {
    const viewNode = viewRef.current;
    const nodeHandle = (0, _reactNative.findNodeHandle)(scrollableRef.current);

    const onSuccess = (_x, y) => {
      listVerticalOffset.value = y;
    };

    const onFail = () => {
      console.log("## nested draggable list measure fail");
    }; //@ts-ignore


    viewNode.measureLayout(nodeHandle, onSuccess, onFail);
  };

  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    ref: viewRef,
    onLayout: onListContainerLayout
  }, /*#__PURE__*/_react.default.createElement(_DraggableFlatList.default, _extends({
    activationDistance: 20,
    autoscrollSpeed: 50,
    scrollEnabled: false
  }, props, {
    outerScrollOffset: outerScrollOffset,
    onDragBegin: function () {
      var _props$onDragBegin;

      setOuterScrollEnabled(false);

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      (_props$onDragBegin = props.onDragBegin) === null || _props$onDragBegin === void 0 ? void 0 : _props$onDragBegin.call(props, ...args);
    },
    onDragEnd: function () {
      var _props$onDragEnd;

      for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
        args[_key2] = arguments[_key2];
      }

      (_props$onDragEnd = props.onDragEnd) === null || _props$onDragEnd === void 0 ? void 0 : _props$onDragEnd.call(props, ...args);
      setOuterScrollEnabled(true);
    },
    onAnimValInit: animVals => {
      var _props$onAnimValInit;

      setListHoverOffset(animVals.hoverOffset);
      setAnimVals({ ...animVals,
        hoverOffset
      });
      (_props$onAnimValInit = props.onAnimValInit) === null || _props$onAnimValInit === void 0 ? void 0 : _props$onAnimValInit.call(props, animVals);
    }
  })));
}
//# sourceMappingURL=NestableDraggableFlatList.js.map