"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAutoScroll = useAutoScroll;

var _reactNativeReanimated = require("react-native-reanimated");

var _constants = require("../constants");

var _propsContext = require("../context/propsContext");

var _animatedValueContext = require("../context/animatedValueContext");

var _refContext = require("../context/refContext");

function useAutoScroll() {
  const {
    flatlistRef
  } = (0, _refContext.useRefs)();
  const {
    autoscrollThreshold = _constants.DEFAULT_PROPS.autoscrollThreshold,
    autoscrollSpeed = _constants.DEFAULT_PROPS.autoscrollSpeed
  } = (0, _propsContext.useProps)();
  const {
    scrollOffset,
    scrollViewSize,
    containerSize,
    activeCellSize,
    hoverOffset,
    activeIndexAnim
  } = (0, _animatedValueContext.useAnimatedValues)();
  const hoverScreenOffset = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return hoverOffset.value - scrollOffset.value;
  }, []);
  const isScrolledUp = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return scrollOffset.value - _constants.SCROLL_POSITION_TOLERANCE <= 0;
  }, []);
  const isScrolledDown = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return scrollOffset.value + containerSize.value + _constants.SCROLL_POSITION_TOLERANCE >= scrollViewSize.value;
  }, []);
  const distToTopEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return Math.max(0, hoverScreenOffset.value);
  }, []);
  const distToBottomEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    const hoverPlusActiveCell = hoverScreenOffset.value + activeCellSize.value;
    return Math.max(0, containerSize.value - hoverPlusActiveCell);
  }, []);
  const isAtTopEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return distToTopEdge.value <= autoscrollThreshold;
  });
  const isAtBottomEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return distToBottomEdge.value <= autoscrollThreshold;
  }, []);
  const scrollTarget = (0, _reactNativeReanimated.useSharedValue)(0);
  const dragIsActive = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return activeIndexAnim.value >= 0;
  }, []);
  (0, _reactNativeReanimated.useAnimatedReaction)(() => {
    return dragIsActive.value;
  }, (cur, prev) => {
    if (cur && !prev) {
      scrollTarget.value = scrollOffset.value;
    }
  });
  const shouldAutoScroll = (0, _reactNativeReanimated.useDerivedValue)(() => {
    const scrollTargetDiff = Math.abs(scrollTarget.value - scrollOffset.value);
    const hasScrolledToTarget = scrollTargetDiff < _constants.SCROLL_POSITION_TOLERANCE;
    const isAtEdge = isAtTopEdge.value || isAtBottomEdge.value;
    const topDisabled = isAtTopEdge.value && isScrolledUp.value;
    const bottomDisabled = isAtBottomEdge.value && isScrolledDown.value;
    const isEdgeDisabled = topDisabled || bottomDisabled;
    const cellIsActive = activeIndexAnim.value >= 0;
    return hasScrolledToTarget && isAtEdge && !isEdgeDisabled && cellIsActive;
  });

  function scrollToInternal(offset) {
    if (flatlistRef && "current" in flatlistRef) {
      var _flatlistRef$current;

      (_flatlistRef$current = flatlistRef.current) === null || _flatlistRef$current === void 0 ? void 0 : _flatlistRef$current.scrollToOffset({
        offset,
        animated: true
      });
    }
  }

  (0, _reactNativeReanimated.useDerivedValue)(() => {
    if (!shouldAutoScroll.value) return;
    const distFromEdge = isAtTopEdge.value ? distToTopEdge.value : distToBottomEdge.value;
    const speedPct = 1 - distFromEdge / autoscrollThreshold;
    const offset = speedPct * autoscrollSpeed;
    const targetOffset = isAtTopEdge.value ? Math.max(0, scrollOffset.value - offset) : scrollOffset.value + offset;
    scrollTarget.value = targetOffset; // Reanimated scrollTo is crashing on android. use 'regular' scrollTo until figured out.
    // scrollTo(scrollViewRef, targetX, targetY, true);

    (0, _reactNativeReanimated.runOnJS)(scrollToInternal)(targetOffset);
  }, []);
  return null;
}
//# sourceMappingURL=useAutoScroll.js.map