"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useIdentityRetainingCallback = useIdentityRetainingCallback;

var _react = require("react");

// Utility hook that returns a function that never has stale dependencies, but
// without changing identity, as a useCallback with dep array would.
// Useful for functions that depend on external state, but
// should not trigger effects when that external state changes.
function useIdentityRetainingCallback(fn) {
  const fnRef = (0, _react.useRef)(fn);
  fnRef.current = fn;
  const identityRetainingFn = (0, _react.useCallback)(function () {
    return fnRef.current(...arguments);
  }, []);
  return identityRetainingFn;
}
//# sourceMappingURL=useIdentityRetainingCallback.js.map