"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useNestedAutoScroll = useNestedAutoScroll;

var _reactNativeReanimated = require("react-native-reanimated");

var _nestableScrollContainerContext = require("../context/nestableScrollContainerContext");

var _constants = require("../constants");

// This is mostly copied over from the main react-native-draggable-flatlist
// useAutoScroll hook with a few notable exceptions:
// - Since animated values are now coming in via a callback,
//   we won't guarantee they exist (and default them if not).
// - Outer scrollable is a ScrollView, not a FlatList
// TODO: see if we can combine into a single shared `useAutoScroll()` hook
function useNestedAutoScroll(params) {
  const {
    outerScrollOffset,
    containerSize,
    scrollableRef,
    scrollViewSize
  } = (0, _nestableScrollContainerContext.useSafeNestableScrollContainerContext)();
  const DUMMY_VAL = (0, _reactNativeReanimated.useSharedValue)(0);
  const {
    hoverOffset = DUMMY_VAL,
    activeCellSize = DUMMY_VAL,
    autoscrollSpeed = 100,
    autoscrollThreshold = 30,
    isDraggingCell = DUMMY_VAL,
    isTouchActiveNative = DUMMY_VAL
  } = params;
  const hoverScreenOffset = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return hoverOffset.value - outerScrollOffset.value;
  }, []);
  const isScrolledUp = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return outerScrollOffset.value - _constants.SCROLL_POSITION_TOLERANCE <= 0;
  }, []);
  const isScrolledDown = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return outerScrollOffset.value + containerSize.value + _constants.SCROLL_POSITION_TOLERANCE >= scrollViewSize.value;
  }, []);
  const distToTopEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return Math.max(0, hoverScreenOffset.value);
  }, [hoverScreenOffset]);
  const distToBottomEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    const dist = containerSize.value - (hoverScreenOffset.value + activeCellSize.value);
    return Math.max(0, dist);
  }, [hoverScreenOffset, activeCellSize, containerSize]);
  const isAtTopEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return distToTopEdge.value <= autoscrollThreshold;
  }, []);
  const isAtBottomEdge = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return distToBottomEdge.value <= autoscrollThreshold;
  });
  const scrollTarget = (0, _reactNativeReanimated.useSharedValue)(0);
  (0, _reactNativeReanimated.useAnimatedReaction)(() => {
    return isDraggingCell.value;
  }, (cur, prev) => {
    if (cur && !prev) {
      scrollTarget.value = outerScrollOffset.value;
    }
  }, [activeCellSize]);

  function scrollToInternal(y) {
    var _scrollableRef$curren;

    (_scrollableRef$curren = scrollableRef.current) === null || _scrollableRef$curren === void 0 ? void 0 : _scrollableRef$curren.scrollTo({
      y,
      animated: true
    });
  }

  (0, _reactNativeReanimated.useDerivedValue)(() => {
    const isAtEdge = isAtTopEdge.value || isAtBottomEdge.value;
    const topDisabled = isAtTopEdge.value && isScrolledUp.value;
    const bottomDisabled = isAtBottomEdge.value && isScrolledDown.value;
    const isEdgeDisabled = topDisabled || bottomDisabled;
    const scrollTargetDiff = Math.abs(scrollTarget.value - outerScrollOffset.value);
    const scrollInProgress = scrollTargetDiff > _constants.SCROLL_POSITION_TOLERANCE;
    const shouldScroll = isAtEdge && !isEdgeDisabled && isDraggingCell.value && isTouchActiveNative.value && !scrollInProgress;
    const distFromEdge = isAtTopEdge.value ? distToTopEdge.value : distToBottomEdge.value;
    const speedPct = 1 - distFromEdge / autoscrollThreshold;
    const offset = speedPct * autoscrollSpeed;
    const targetOffset = isAtTopEdge.value ? Math.max(0, outerScrollOffset.value - offset) : outerScrollOffset.value + offset;

    if (shouldScroll) {
      scrollTarget.value = targetOffset; // Reanimated scrollTo is crashing on android. use 'regular' scrollTo until figured out.
      // scrollTo(scrollViewRef, 0, scrollTarget.value, true)

      (0, _reactNativeReanimated.runOnJS)(scrollToInternal)(targetOffset);
    }
  }, [autoscrollSpeed, autoscrollThreshold, isDraggingCell]);
  return null;
}
//# sourceMappingURL=useNestedAutoScroll.js.map