"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useOnCellActiveAnimation = useOnCellActiveAnimation;

var _react = require("react");

var _reactNativeReanimated = require("react-native-reanimated");

var _constants = require("../constants");

var _animatedValueContext = require("../context/animatedValueContext");

var _cellContext = require("../context/cellContext");

function useOnCellActiveAnimation() {
  let {
    animationConfig
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
    animationConfig: {}
  };
  const animationConfigRef = (0, _react.useRef)(animationConfig);
  animationConfigRef.current = animationConfig;
  const isActive = (0, _cellContext.useIsActive)();
  const {
    isTouchActiveNative
  } = (0, _animatedValueContext.useAnimatedValues)();
  const onActiveAnim = (0, _reactNativeReanimated.useDerivedValue)(() => {
    const toVal = isActive && isTouchActiveNative.value ? 1 : 0;
    const animConfig = {}; // spread operator and Object.assign don't work within worklets

    for (let key in _constants.DEFAULT_ANIMATION_CONFIG) {
      const k = key;
      const v = _constants.DEFAULT_ANIMATION_CONFIG[k]; // @ts-ignore

      animConfig[k] = v;
    }

    for (let key in animationConfigRef.current) {
      const k = key;
      const v = animationConfigRef.current[k]; // @ts-ignore

      animConfig[k] = v;
    }

    return (0, _reactNativeReanimated.withSpring)(toVal, _constants.DEFAULT_ANIMATION_CONFIG);
  }, [isActive]);
  return {
    isActive,
    onActiveAnim
  };
}
//# sourceMappingURL=useOnCellActiveAnimation.js.map