function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useRef, useState } from "react";
import { findNodeHandle, LogBox } from "react-native";
import Animated, { useDerivedValue, useSharedValue } from "react-native-reanimated";
import DraggableFlatList from "../components/DraggableFlatList";
import { useSafeNestableScrollContainerContext } from "../context/nestableScrollContainerContext";
import { useNestedAutoScroll } from "../hooks/useNestedAutoScroll";
export function NestableDraggableFlatList(props) {
  const hasSuppressedWarnings = useRef(false);

  if (!hasSuppressedWarnings.current) {
    LogBox.ignoreLogs(["VirtualizedLists should never be nested inside plain ScrollViews with the same orientation because it can break windowing"]); // Ignore log notification by message
    //@ts-ignore

    console.reportErrorsAsExceptions = false;
    hasSuppressedWarnings.current = true;
  }

  const {
    scrollableRef,
    outerScrollOffset,
    setOuterScrollEnabled
  } = useSafeNestableScrollContainerContext();
  const listVerticalOffset = useSharedValue(0);
  const viewRef = useRef(null);
  const [animVals, setAnimVals] = useState({});
  const defaultHoverOffset = useSharedValue(0);
  const [listHoverOffset, setListHoverOffset] = useState(defaultHoverOffset);
  const hoverOffset = useDerivedValue(() => {
    return listHoverOffset.value + listVerticalOffset.value;
  }, [listHoverOffset]);
  useNestedAutoScroll({ ...animVals,
    hoverOffset
  });

  const onListContainerLayout = async () => {
    const viewNode = viewRef.current;
    const nodeHandle = findNodeHandle(scrollableRef.current);

    const onSuccess = (_x, y) => {
      listVerticalOffset.value = y;
    };

    const onFail = () => {
      console.log("## nested draggable list measure fail");
    }; //@ts-ignore


    viewNode.measureLayout(nodeHandle, onSuccess, onFail);
  };

  return /*#__PURE__*/React.createElement(Animated.View, {
    ref: viewRef,
    onLayout: onListContainerLayout
  }, /*#__PURE__*/React.createElement(DraggableFlatList, _extends({
    activationDistance: 20,
    autoscrollSpeed: 50,
    scrollEnabled: false
  }, props, {
    outerScrollOffset: outerScrollOffset,
    onDragBegin: function () {
      var _props$onDragBegin;

      setOuterScrollEnabled(false);

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      (_props$onDragBegin = props.onDragBegin) === null || _props$onDragBegin === void 0 ? void 0 : _props$onDragBegin.call(props, ...args);
    },
    onDragEnd: function () {
      var _props$onDragEnd;

      for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
        args[_key2] = arguments[_key2];
      }

      (_props$onDragEnd = props.onDragEnd) === null || _props$onDragEnd === void 0 ? void 0 : _props$onDragEnd.call(props, ...args);
      setOuterScrollEnabled(true);
    },
    onAnimValInit: animVals => {
      var _props$onAnimValInit;

      setListHoverOffset(animVals.hoverOffset);
      setAnimVals({ ...animVals,
        hoverOffset
      });
      (_props$onAnimValInit = props.onAnimValInit) === null || _props$onAnimValInit === void 0 ? void 0 : _props$onAnimValInit.call(props, animVals);
    }
  })));
}
//# sourceMappingURL=NestableDraggableFlatList.js.map